/**************************************************************************
**  (c) Copyright 2012, Andromeda Technology & Automation
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : inetaddress.h
**      SYSTEM NAME    : Network and socket classes
**      VERSION NUMBER : 0.1
**
**  DESCRIPTION      :  Internet address class definition
**
**  EXPORTED OBJECTS : class InternetAddress
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Mar 02, 2012
**      LAST UPDATE     : Mar 02, 2012
**      MODIFICATIONS   : 
**************************************************************************/

#ifndef _INETADDRESS_H_
#define _INETADDRESS_H_

#include <arpa/inet.h>
#include <netdb.h>
#include <AXE/String.h>

/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
**  NAME           : InternetAddress - IPv4 or IPv6 address handling.
**  MEMBERS        : af        : The address family, AF_UNSPEC, AF_INET of AF_INET6
**                   inet_addr : The address itself, in network byte order.
**  OPERATORS      : None
**  METHODS        : address_family()
**
**  DESCRIPTION    : An InternetAddress object holds an IP address which can be
**                   either an IPv4 address or an IPv6 address.
**                   Its main purpose is to perform the conversion between addresses
**                   in network byte order end textual representations of an IP address.
**
**
**  RELATIONS      : 
**  SEE ALSO       : inet_pton(3), inet_ntop()
**  LAST MODIFIED  : Mar 02, 2012
**+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
*/

class InternetAddress
{
   int af;
   unsigned char inet_addr[16];


public:

   InternetAddress()
   {
      af = AF_UNSPEC;
   }

   InternetAddress(const char *);      // InternetAddress x = "127.0.0.1"
   InternetAddress(const struct addrinfo *);
   InternetAddress(const struct in6_addr addr);
   InternetAddress(const struct in_addr addr);

   operator String();

   int address_family()
   {
      return af;
   }

   struct in6_addr get_in6_addr();
   struct in_addr  get_in_addr();
};

#endif // _INETADDRESS_H_
