/**************************************************************************
**  (c) Copyright 2012, Andromeda Technology & Automation
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : port.h
**      SYSTEM NAME    : Network and socket classes
**      VERSION NUMBER : 0.1
**
**  DESCRIPTION      :  Port class definition
**
**  EXPORTED OBJECTS : class Port
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Mar 02, 2012
**      LAST UPDATE     : Mar 08, 2012
**      MODIFICATIONS   : 
**************************************************************************/

#ifndef _PORT_H_
#define _PORT_H_

#include <sys/socket.h>   //  For types and constants (like SOCK_STREAM)

/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
**  NAME           : Port - A class that represents a port for services.
**  MEMBERS        : port      : The port number.
**                   sockettype: The type of socket on which the service is available.
**  OPERATORS      : ==, !=
**                   unsigned short : Convert to port number in host byte order.
**  METHODS        : get_port()      : The port number in network byte order.
**                   get_sockettype(): Find the name if the port in known.
**
**  DESCRIPTION    : 
**
**
**  RELATIONS      : 
**  SEE ALSO       : 
**  LAST MODIFIED  : Mar 08, 2012
**+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
*/

class Port
{
   in_port_t     port;
   int           socktype;

public:

   Port()
   {
      port = 0;
      socktype = 0;
   }

   Port(in_port_t p, int st)
   {
      port = p;
      socktype = st;
   }

   Port(unsigned short p)
   {
      port = htons(p);
      socktype = 0;
   }

   in_port_t get_port()
   {
      return port;
   }

   int get_sockettype()
   {
      return socktype;
   }

   operator unsigned short ()
   {
      return ntohs(port);
   }
};

#endif // _PORT_H_
