/**************************************************************************
**  (c) Copyright 2012, Andromeda Technology & Automation
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : host.cpp
**      SYSTEM NAME    : Network and socket classes
**      VERSION NUMBER : 0.1
**
**  DESCRIPTION      :  Host class implementation
**
**  EXPORTED OBJECTS : class Host
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Mar 02, 2012
**      LAST UPDATE     : Mar 05, 2012
**      MODIFICATIONS   : 
**************************************************************************/

#include "host.h"


/*=========================================================================
**  NAME           : Host::FindAddress
**  SYNOPSIS       :
**  PARAMETERS     :
**  RETURN VALUE   : List of InternetAddress objects
**
**  DESCRIPTION    : Find all addresses given the hostname.
**
**  VARS USED      :
**  VARS CHANGED   :
**  FUNCTIONS USED :
**  SEE ALSO       :
**  LAST MODIFIED  : Mar 05, 2012
**=========================================================================
*/

std::list<InternetAddress> Host::FindAddress()
{
   struct addrinfo hints;
   struct addrinfo *res, *rp;

   hints.ai_family = AF_UNSPEC;    /* Allow IPv4 or IPv6 */
   hints.ai_socktype = SOCK_DGRAM; /* Datagram socket */
   hints.ai_flags = 0;
   hints.ai_protocol = 0;          /* Any protocol */
   hints.ai_canonname = NULL;
   hints.ai_addr = NULL;
   hints.ai_next = NULL;

   int error = getaddrinfo(name, NULL, &hints, &res);

   addresses.clear();
   for (rp = res; rp != NULL; rp = rp->ai_next)
   {
      InternetAddress ipaddr(rp);
      addresses.push_back(ipaddr);
   }

   freeaddrinfo(res);

   return addresses;
}

