/**************************************************************************
**  (c) Copyright 2012, Andromeda Technology & Automation
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : service.cpp
**      SYSTEM NAME    : Network and socket classes
**      VERSION NUMBER : 0.1
**
**  DESCRIPTION      :  Service class implementation
**
**  EXPORTED OBJECTS : class Service
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Mar 02, 2012
**      LAST UPDATE     : Mar 07, 2012
**      MODIFICATIONS   : 
**************************************************************************/

#include "service.h"


/*=========================================================================
**  NAME           : Service::FindAddress
**  SYNOPSIS       :
**  PARAMETERS     :
**  RETURN VALUE   : List of port numbers
**
**  DESCRIPTION    : Find all ports given the service name.
**
**  VARS USED      :
**  VARS CHANGED   :
**  FUNCTIONS USED :
**  SEE ALSO       :
**  LAST MODIFIED  : Mar 05, 2012
**=========================================================================
*/

std::list<Port> Service::FindAddress()
{
   struct addrinfo hints;
   struct addrinfo *res, *rp;

   hints.ai_family = AF_UNSPEC;    /* Allow IPv4 or IPv6 */
   hints.ai_socktype = SOCK_DGRAM; /* Datagram socket */
   hints.ai_flags = 0;
   hints.ai_protocol = 0;          /* Any protocol */
   hints.ai_canonname = NULL;
   hints.ai_addr = NULL;
   hints.ai_next = NULL;

   int error = getaddrinfo(NULL, name, NULL, &res);

   ports.clear();
   for (rp = res; rp != NULL; rp = rp->ai_next)
   {
      struct sockaddr_in *sa;
      sa = (struct sockaddr_in *)rp->ai_addr;
      std::cout << "Port " << htons(sa->sin_port) << " socket " << rp->ai_socktype << "\n";

      Port p(sa->sin_port, rp->ai_socktype);
      ports.push_back(p);
   }

   freeaddrinfo(res);

   return ports;
}

