/**************************************************************************
**  (c) Copyright 2012, Andromeda Technology & Automation
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : socket.cpp
**      SYSTEM NAME    : Network and socket classes
**      VERSION NUMBER : 0.1
**
**  DESCRIPTION      :  SocketAddress, Socket and derived classes implementation
**
**  EXPORTED OBJECTS : class SocketAddress, class Socket
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Mar 02, 2012
**      LAST UPDATE     : Mar 08, 2012
**      MODIFICATIONS   : 
**************************************************************************/

#include "socket.h"


/*=========================================================================
**  NAME           : IPSocketAddress::get_sockaddr
**  SYNOPSIS       :
**  PARAMETERS     :
**  RETURN VALUE   : Pointer to the low-level socketaddress structure
**
**  DESCRIPTION    : 
**
**  VARS USED      :
**  VARS CHANGED   :
**  FUNCTIONS USED :
**  SEE ALSO       :
**  LAST MODIFIED  : Mar 08, 2012
**=========================================================================
*/

struct sockaddr * IPSocketAddress::get_sockaddr()
{
   if (IPaddress.address_family() == AF_INET)
   {
      //  Create an IPv4 socket address

      in.sin_family = AF_INET;
      in.sin_port   = prt.get_port();
      in.sin_addr   = IPaddress.get_in_addr();

      return (sockaddr *)&in;
   }
   else if (IPaddress.address_family() == AF_INET6)
   {
      //  Create an IPv6 socket address

      in6.sin6_family = AF_INET6;
      in6.sin6_port   = prt.get_port();
      in6.sin6_addr   = IPaddress.get_in6_addr();
      in6.sin6_flowinfo = 0;
      in6.sin6_scope_id = 0;

      return (sockaddr *)&in6;
   }
   else
   {
      return 0;
   }
}

socklen_t IPSocketAddress::get_socklen()
{
   if (IPaddress.address_family() == AF_INET)
   {
      return sizeof(struct sockaddr_in);
   }
   else if (IPaddress.address_family() == AF_INET6)
   {
      return sizeof(struct sockaddr_in6);
   }
   else
   {
      return 0;
   }
}

int StreamSocket::Connect(SocketAddress &sa) 
{
   int res;

   if (fd == -1)
   {
      fd = socket(sa.address_family(), SOCK_STREAM, 0);
   }
   res = connect(fd, sa.get_sockaddr(), sa.get_socklen());
   return res;
}

int StreamSocket::Listen(SocketAddress &sa) 
{
   int res;

   if (fd == -1)
   {
      fd = socket(sa.address_family(), SOCK_STREAM, 0);
   }
   res = bind(fd, sa.get_sockaddr(), sa.get_socklen());
   if (res == 0)
   {
      res = listen(fd, 100);
   }
   return res;
}

StreamSocket StreamSocket::Accept()
{
   struct sockaddr_in6  peer_address;
   socklen_t            peer_len;

   StreamSocket         peer;

   peer.fd = accept(fd, (sockaddr *)&peer_address, &peer_len);

   return peer;
}

